﻿--[[
AutoRole.lua

This file is part of AutoRole. <http://www.curse.com/addons/wow/auto-role>
	
Copyright © 2010-2013 Matthew Casey <mdcasey@chabloom.com>

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

	http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
]]
AutoRole = LibStub("AceAddon-3.0"):NewAddon("AutoRole", "AceConsole-3.0", "AceEvent-3.0")
local AUTOROLE_VERSION = GetAddOnMetadata("AutoRole", "Version")
local currentRole = nil;
local currentSpec = nil;
local currentSpecName = nil;
local isPrinted = false;

function AutoRole:OnInitialize()
	self:RegisterEvent("ACTIVE_TALENT_GROUP_CHANGED", "SetRole")
	self:RegisterEvent("GROUP_ROSTER_UPDATE", "SetRole")
	self:RegisterEvent("PLAYER_REGEN_ENABLED", "SetRole")
	RolePollPopup:SetScript("OnShow", function() RolePollPopupAcceptButton:Click() end)
end

function AutoRole:OnEnable()
	self:RegisterChatCommand("AR", "SlashCommand")
	self:RegisterChatCommand("AUTOROLE", "SlashCommand")
	self:ShowVersion()
end

function AutoRole:SetRole(event)
	currentSpec = GetSpecialization()
	currentRole = GetSpecializationRole(currentSpec)
	currentSpecName = currentSpec and select(2, GetSpecializationInfo(currentSpec))
	
	if (event == "ACTIVE_TALENT_GROUP_CHANGED") then
		isSet = false
	end
	
	if InCombatLockdown() then
		if not isPrinted then
			self:Print("Disabled during combat")
			isPrinted = true;
		end
	else
		if (currentSpec == nil) and not isSet then
			UnitSetRole("player", "NONE")
		else
			UnitSetRole("player", currentRole)
		end
	end
end

function AutoRole:ShowRole()
	currentSpec = GetSpecialization()
	currentRole = GetSpecializationRole(currentSpec)
	currentSpecName = currentSpec and select(2, GetSpecializationInfo(currentSpec))

	if (currentSpec == nil) then
		self:Print("Role set to NONE because you have no specialization.")
	else
		self:Print("Role set to", currentRole, "because your specialization is", currentSpecName)
	end
end

function AutoRole:ShowVersion()
	self:Print("AutoRole version", AUTOROLE_VERSION)
end

function AutoRole:SlashCommand(input)
	if input == "version" then
		self:ShowVersion()
	elseif input == "showrole" then
		self:ShowRole()
	else
		self:Print("/ar showrole")
		self:Print("/ar version")
	end
end